import { DomainObject } from 'domain-objects';
import { NormalizeCacheValueMethod } from '../../domain/NormalizeCacheValueMethod';
export declare const getCacheReferenceKeyForDomainObject: (dobj: DomainObject<any>) => string;
/**
 * a method which can be used to normalize a cache value by extracting references the domain-objects contained within it
 *
 * for example
 * - from
 *   ```ts
 *       {
 *         'value': {
 *           'ships': [
 *             new Ship({ id: 1, name: 'boaty mcboatface' }),
 *             new Ship({ id: 2, name: 'sea biscuit' }),
 *             new Ship({ id: 1, name: 'boaty mcboatface' }
 *           ]
 *         }
 *       }
 *   ```
 * - to
 *   ```ts
 *       {
 *         'value': {
 *           'ships': [
 *             '.cache.ref.Ship.1',
 *             '.cache.ref.Ship.2',
 *             '.cache.ref.Ship.1',
 *           ]
 *         },
 *         'references': {
 *           '.cache.ref.Ship.1}': new Ship({ id: 1, name: 'boaty mcboatface' ),
 *           '.cache.ref.Ship.2}': new Ship({ id: 2, name: 'sea biscuit' )
 *         }
 *       }
 *   ```
 */
export declare const normalizeDomainObjectReferences: NormalizeCacheValueMethod;
