import { SimpleAsyncCache, SimpleCache } from 'with-simple-caching';
import { SerializableObject } from '../../domain/NormalizeCacheValueMethod';
export declare const CACHE_NORMALIZATION_FOREIGN_KEY_REGEXP: RegExp;
export declare class CouldNotDereferenceError extends Error {
    constructor({ referenceKey }: {
        referenceKey: string;
    });
}
/**
 * a utility which dereferences values in a cached output, ensuring the output is fully hydrated
 *
 * specifically
 * - looks up the value of each reference in the .get output
 * - replaces the reference in the .get output with the true value
 * - does so recursively
 *
 * usecases
 * - normalizing data that changes from multiple operates into its own cache key, to enable automatic cache updates
 *
 * note
 * - this is typically used to denormalize output normalized with the `withNormalization` method
 */
export declare const withDenormalization: <T extends SerializableObject>(cache: SimpleCache<T>) => SimpleAsyncCache<T>;
