"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const withDenormalization_1 = require("./withDenormalization");
describe('withDenormalization', () => {
    const exampleStore = {};
    const cacheGetMock = jest.fn((key) => exampleStore[key]);
    const cacheSetMock = jest.fn((key, value) => (exampleStore[key] = value));
    const cache = {
        get: cacheGetMock,
        set: cacheSetMock,
    };
    const cacheWithDenormalization = (0, withDenormalization_1.withDenormalization)(cache);
    it('should be able to denormalize a cached value equal to a reference', () => __awaiter(void 0, void 0, void 0, function* () {
        // set the reference
        yield cache.set('.cache.ref.Ship.1', '__SHIP__');
        // set an item which uses the reference
        yield cache.set('__key__', '.cache.ref.Ship.1');
        // lookup the item with denormalization
        const found = yield cacheWithDenormalization.get('__key__');
        // prove that it was denormalized successfully
        expect(found).toEqual('__SHIP__');
    }));
    it('should be able to denormalize a cached value with nested references', () => __awaiter(void 0, void 0, void 0, function* () {
        // set the reference
        yield cache.set('.cache.ref.Ship.1', '__SHIP__');
        // set an item which uses the reference
        yield cache.set('__key__', { ship: '.cache.ref.Ship.1', color: 'green' });
        // lookup the item with denormalization
        const found = yield cacheWithDenormalization.get('__key__');
        // prove that it was denormalized successfully
        expect(found).toEqual({ ship: '__SHIP__', color: 'green' });
    }));
    it('should be able to denormalize a cached value with deeply nested references', () => __awaiter(void 0, void 0, void 0, function* () {
        // set the reference
        yield cache.set('.cache.ref.Ship.1', '__SHIP__');
        yield cache.set('.cache.ref.Geocode.3', '__GEOCODE__');
        // set an item which uses the reference
        yield cache.set('__key__', {
            ship: '.cache.ref.Ship.1',
            color: 'green',
            position: { geocode: '.cache.ref.Geocode.3' },
        });
        // lookup the item with denormalization
        const found = yield cacheWithDenormalization.get('__key__');
        // prove that it was denormalized successfully
        expect(found).toEqual({
            ship: '__SHIP__',
            color: 'green',
            position: { geocode: '__GEOCODE__' },
        });
    }));
    it('should preserve the shape of arrays', () => __awaiter(void 0, void 0, void 0, function* () {
        // set an item which contains an array
        yield cache.set('__key__', { colors: ['green', 'blue'] });
        // lookup the item with denormalization
        const found = yield cacheWithDenormalization.get('__key__');
        // prove that it was denormalized successfully
        expect(found).toEqual({ colors: ['green', 'blue'] });
    }));
});
//# sourceMappingURL=withDenormalization.test.js.map