"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withNormalization = void 0;
const UnexpectedCodePathError_1 = require("../../utils/errors/UnexpectedCodePathError");
const withDenormalization_1 = require("./withDenormalization");
/**
 * a wrapper which augments a cache to add normalization on set and denormalization on get
 */
const withNormalization = (cache, { normalize, referenceSecondsUntilExpiration = 30 * 24 * 60 * 60, }) => {
    const cacheWithDenormalization = (0, withDenormalization_1.withDenormalization)(cache);
    return Object.assign(Object.assign({}, cacheWithDenormalization), { set: (key, value, options) => __awaiter(void 0, void 0, void 0, function* () {
            // normalize the value
            const { value: normalized, references } = normalize({ value });
            // set the normalized value into the cache
            const setNormalizedResult = cache.set(key, normalized, options);
            // set each reference into the cache
            const setReferencePromises = Object.entries(references).map(([refKey, refValue]) => {
                // sanity check that the reference will be able to be denormalized later on
                if (!withDenormalization_1.CACHE_NORMALIZATION_FOREIGN_KEY_REGEXP.test(refKey))
                    throw new UnexpectedCodePathError_1.UnexpectedCodePathError('detected an invalid normalization referenceKey', { refKey, refValue });
                // set the reference into the cache
                return cache.set(refKey, refValue, {
                    secondsUntilExpiration: referenceSecondsUntilExpiration,
                });
            });
            // await all of the sets resolving
            yield Promise.all([setNormalizedResult, ...setReferencePromises]);
        }) });
};
exports.withNormalization = withNormalization;
//# sourceMappingURL=withNormalization.js.map