"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const withSerialization_1 = require("./withSerialization");
describe('withSerialization', () => {
    const exampleStore = {};
    const cacheGetMock = jest.fn((key) => exampleStore[key]);
    const cacheSetMock = jest.fn((key, value) => (exampleStore[key] = value));
    const cache = {
        get: cacheGetMock,
        set: cacheSetMock,
    };
    const cacheWithSerialization = (0, withSerialization_1.withSerialization)(cache);
    it('should serialize values on set', () => __awaiter(void 0, void 0, void 0, function* () {
        yield cacheWithSerialization.set('__key__', { hello: 'world' });
        expect(cacheSetMock).toHaveBeenCalledWith('__key__', '{"hello":"world"}', undefined);
    }));
    it('should deserialize values on get', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield cacheWithSerialization.get('__key__');
        expect(result).toEqual({ hello: 'world' });
    }));
});
//# sourceMappingURL=withSerialization.test.js.map